@@ -27,7 +27,7 @@ with project_dir.joinpath("pyproject.toml").open("rb") as pyproject_file:
     pyproject = tomllib.load(pyproject_file)
 project = pyproject["project"]
 project_name = project["name"]
-devdeps = [dep for dep in pyproject["tool"]["uv"]["dev-dependencies"] if not dep.startswith("-e")]
+devdeps = [dep for dep in pyproject["dependency-groups"]["dev"] if not dep.startswith("-e")]
 
 PackageMetadata = dict[str, Union[str, Iterable[str]]]
 Metadata = dict[str, PackageMetadata]
