@@ -4,13 +4,6 @@ from __future__ import annotations
 
 import ast
 
-# YORE: Bump 1: Replace `_logger` with `logger` within file.
-# YORE: Bump 1: Replace `get_logger` with `logger` within line.
-from _griffe.logger import get_logger
-
-# YORE: Bump 1: Remove line.
-_logger = get_logger("griffe.agents.nodes._docstrings")
-
 
 def get_docstring(
     node: ast.AST,
