@@ -189,18 +189,7 @@ class GriffeLoader:
         # Pre-emptively expand exports (`__all__` values),
         # as well as wildcard imports (without ever loading additional packages).
         # This is a best-effort to return the most correct API data
-        # before firing the `on_package_loaded` event,
-        # because extensions registering hooks for this event
-        # might trigger computation of inherited members,
-        # which are cached, and could be cached too early
-        # (aliases to base class still being unresolvable,
-        # preventing to fetch some inherited members).
-        #
-        # Another solution to this "too-early-computation-of-inherited-members"
-        # issue would be to stop caching resolved bases and inherited members,
-        # but we would have to measure the performance impact of this change,
-        # as each use of `obj["name"]` would compute resolved bases, MRO
-        # and inherited members again.
+        # before firing the `on_package_loaded` event.
         #
         # Packages that wildcard imports from external, non-loaded packages
         # will still have incomplete data, requiring subsequent calls to
@@ -261,14 +250,18 @@ class GriffeLoader:
                 resolved |= next_resolved
                 unresolved |= next_unresolved
             logger.debug(
-                "Iteration %s finished, {len(resolved)} aliases resolved, still {len(unresolved)} to go",
+                "Iteration %s finished, %s aliases resolved, still %s to go",
                 iteration,
+                len(resolved),
+                len(unresolved),
             )
         return unresolved, iteration
 
     def expand_exports(self, module: Module, seen: set | None = None) -> None:
         """Expand exports: try to recursively expand all module exports (`__all__` values).
 
+        See also: [`Module.exports`][griffe.Module.exports].
+
         Parameters:
             module: The module to recurse on.
             seen: Used to avoid infinite recursion.
@@ -314,6 +307,8 @@ class GriffeLoader:
     ) -> None:
         """Expand wildcards: try to recursively expand all found wildcards.
 
+        See also: [`Alias.wildcard`][griffe.Alias.wildcard].
+
         Parameters:
             obj: The object and its members to recurse on.
             external: When true, try to load unspecified modules to expand wildcards.
