@@ -1096,6 +1096,32 @@ def test_extract_yielded_type_with_single_return_item(parse_numpy: ParserType, r
     assert yields[0].annotation.name == "int"
 
 
+def test_yield_section_in_property(parse_numpy: ParserType) -> None:
+    """No warnings when parsing Yields section in a property.
+
+    Parameters:
+        parse_numpy: Fixture parser.
+    """
+    docstring = """
+        Summary.
+
+        Yields
+        ------
+        :
+            A number.
+    """
+    sections, warnings = parse_numpy(
+        docstring,
+        parent=Attribute(
+            "prop",
+            annotation=parse_docstring_annotation("Iterator[int]", Docstring("d", parent=Attribute("a"))),
+        ),
+    )
+    assert not warnings
+    yields = sections[1].value
+    assert yields[0].annotation.name == "int"
+
+
 # =============================================================================================
 # Receives sections
 def test_parse_receives_tuple_in_generator(parse_numpy: ParserType) -> None:
